@@ -6,16 +6,14 @@ from typing import Union
 ## @brief Class holding the collection of functions from the Contacts section
 # @details This class handles a collection of all functions that are listed in the Contacts section in the documentation of the signal-cli-rest-api
 # @author Felix Hune
-# @version 1.0
-# @date 2022-12-18
+# @version 1.1
+# @date 2022-12-25
 class Contacts:
 	
-	def __init__(self):
-		with open(os.path.join(pathlib.Path(__file__).parent.resolve(), "config.json"), "r") as f:
-			config = json.load(f)
-		self.address = config["address"]
-		self.port = str(config["port"])
-		self.number = config["number"]
+	def __init__(self, Client):
+		self.address = Client.get_address()
+		self.port = Client.get_port()
+		self.number = Client.get_number()
 		
 	## @brief Update contact
 	# @details Calls the API to update the details of an existing contact or, if not existing, creating a new contact with the given information
