@@ -6,15 +6,14 @@ from typing import Union
 ## @brief Class holding the collection of functions from the Search section
 # @details This class handles a collection of all functions that are listed in the Search section in the documentation of the signal-cli-rest-api
 # @author Felix Hune
-# @version 1.0
-# @date 2022-12-18
+# @version 1.1
+# @date 2022-12-25
 class Search:
 	
-	def __init__(self):
-		with open(os.path.join(pathlib.Path(__file__).parent.resolve(), "config.json"), "r") as f:
-			config = json.load(f)
-		self.address = config["address"]
-		self.port = str(config["port"])
+	def __init__(self, Client):
+		self.address = Client.get_address()
+		self.port = Client.get_port()
+		self.number = Client.get_number()
 	
 	## @brief Search numbers
 	# @details Calls the API checking if the given numbers are registered with the Signal service or not. This isn't working correctly (2022-12-18)
