@@ -8,5 +8,6 @@ from .Identities import Identities
 from .Reactions import Reactions
 from .Search import Search
 from .Contacts import Contacts
+from .Client import Client
 
-__all__ = ['General', 'Devices', 'Groups', 'Messages', 'Attachments', 'Profiles', 'Identities', 'Reactions', 'Search', 'Contacts']
+__all__ = ['General', 'Client', 'Devices', 'Groups', 'Messages', 'Attachments', 'Profiles', 'Identities', 'Reactions', 'Search', 'Contacts']
